@@ -32,6 +32,22 @@ Unauthorized, RequestError
 
 from _server_test import HOST, PORT, run_server_test
 
+
+class RestClientTestCase(unittest.TestCase):
+    
+    def setUp(self):
+        self.transport = transport = HTTPLib2Transport()
+        self.client = RestClient(transport)
+        
+    def testMakeUri(self):
+        self.assert_(self.client.make_uri("http://localhost", "/") == "http://localhost/")
+        self.assert_(self.client.make_uri("http://localhost/") == "http://localhost/")
+        self.assert_(self.client.make_uri("http://localhost/", "/test/echo") == "http://localhost/test/echo")
+        self.assert_(self.client.make_uri("http://localhost/", "/test/echo/") == "http://localhost/test/echo/")
+        self.assert_(self.client.make_uri("http://localhost", "/test/echo/") == "http://localhost/test/echo/")
+        self.assert_(self.client.make_uri("http://localhost", "test/echo") == "http://localhost/test/echo")
+        self.assert_(self.client.make_uri("http://localhost", "test/echo/") == "http://localhost/test/echo/")
+        
 class ResourceTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -124,6 +140,10 @@ class ResourceTestCase(unittest.TestCase):
     def testPostWithQuery(self):
         result = self.res.post('/query', test="testing")
         self.assert_(self.res.response.status == 200)
+    
+    def testPostForm(self):
+        result = self.res.post('/form', payload={ "a": "a", "b": "b" })
+        self.assert_(self.res.response.status == 200)
 
     def testSimplePut(self):
         result = self.res.put(payload="test")
@@ -192,6 +212,8 @@ class ResourceTestCase(unittest.TestCase):
             res = Resource(self.url, transport)
             result = res.get('/auth')
         self.assertRaises(Unauthorized, niettest)
+        
+    
 
  
     
